summaryrefslogtreecommitdiffstats
path: root/shared
diff options
context:
space:
mode:
authorJohannes Dahlström <johannesd@vaadin.com>2014-12-11 17:07:15 +0200
committerJohannes Dahlström <johannesd@vaadin.com>2014-12-11 17:35:40 +0200
commit4f41def1e6cae667d4c39bbff8664895e46d7a76 (patch)
tree80525f18ce0520074c0e2948b9e56403e8536343 /shared
parentb8a38c38caea01eb21ab0e02b77f87bc6bf31214 (diff)
downloadvaadin-framework-4f41def1e6cae667d4c39bbff8664895e46d7a76.tar.gz
vaadin-framework-4f41def1e6cae667d4c39bbff8664895e46d7a76.zip
Remove editor row discard methods; rename "commit" to "save" (#13334)
Change-Id: Ic7cec3c3750db8a2e0b23a4d38f63e9642999e3e
Diffstat (limited to 'shared')
-rw-r--r--shared/src/com/vaadin/shared/ui/grid/EditorRowClientRpc.java14
-rw-r--r--shared/src/com/vaadin/shared/ui/grid/EditorRowServerRpc.java17
2 files changed, 7 insertions, 24 deletions
diff --git a/shared/src/com/vaadin/shared/ui/grid/EditorRowClientRpc.java b/shared/src/com/vaadin/shared/ui/grid/EditorRowClientRpc.java
index d6822cfccc..c72f767f3c 100644
--- a/shared/src/com/vaadin/shared/ui/grid/EditorRowClientRpc.java
+++ b/shared/src/com/vaadin/shared/ui/grid/EditorRowClientRpc.java
@@ -34,14 +34,6 @@ public interface EditorRowClientRpc extends ClientRpc {
void bind(int rowIndex);
/**
- * Tells the client to discard unsaved changes in the editor row.
- *
- * @param rowIndex
- * the index of the edited row
- */
- void discard(int rowIndex);
-
- /**
* Tells the client to cancel editing and hide the editor row.
*
* @param rowIndex
@@ -56,8 +48,8 @@ public interface EditorRowClientRpc extends ClientRpc {
void confirmBind();
/**
- * Confirms a pending {@link EditorRowServerRpc#commit(int) commit request}
- * sent by the client.
+ * Confirms a pending {@link EditorRowServerRpc#save(int) save request} sent
+ * by the client.
*/
- void confirmCommit();
+ void confirmSave();
}
diff --git a/shared/src/com/vaadin/shared/ui/grid/EditorRowServerRpc.java b/shared/src/com/vaadin/shared/ui/grid/EditorRowServerRpc.java
index 25bafe2da1..8215e8963c 100644
--- a/shared/src/com/vaadin/shared/ui/grid/EditorRowServerRpc.java
+++ b/shared/src/com/vaadin/shared/ui/grid/EditorRowServerRpc.java
@@ -37,23 +37,14 @@ public interface EditorRowServerRpc extends ServerRpc {
void bind(int rowIndex);
/**
* Asks the server to commit unsaved changes in the editor row to the data
* source. When a commit request is sent, it must be acknowledged with a
* {@link EditorRowClientRpc#confirmCommit() confirm call}.
*
* @param rowIndex
* the index of the edited row
*/
- void commit(int rowIndex);
-
- /**
- * Asks the server to replace any unsaved changes with values from the data
- * source.
- *
- * @param rowIndex
- * the index of the edited row
- */
- void discard(int rowIndex);
+ void save(int rowIndex);
/**
* Tells the server to cancel editing. When sending a cancel request, the
@@ -37,23 +37,14 @@ public interface EditorRowServerRpc extends ServerRpc {
void bind(int rowIndex);
/**
- * Asks the server to commit unsaved changes in the editor row to the data
- * source. When a commit request is sent, it must be acknowledged with a
- * {@link EditorRowClientRpc#confirmCommit() confirm call}.
+ * Asks the server to save unsaved changes in the editor row to the data
+ * source. When a save request is sent, it must be acknowledged with a
+ * {@link EditorRowClientRpc#confirmSave() confirm call}.
*
* @param rowIndex